@@ -1,4 +1,4 @@
-/* $Id: loadavg.h,v 1.23 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: loadavg.h,v 1.26 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -40,14 +40,14 @@ typedef struct _glibtop_loadavg	glibtop_loadavg;
 
 struct _glibtop_loadavg
 {
-	u_int64_t flags;
+	guint64 flags;
 	double loadavg [3];		/* GLIBTOP_LOADAVG_LOADAVG	*/
-	u_int64_t nr_running,		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
+	guint64 nr_running,		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
 		nr_tasks,		/* GLIBTOP_LOADAVG_NR_TASKS	*/
 		last_pid;		/* GLIBTOP_LOADAVG_LAST_PID	*/
 };
 
-#define glibtop_get_loadavg(loadavg)	glibtop_get_loadavg_l(glibtop_global_server, loadavg)
+void glibtop_get_loadavg(glibtop_loadavg *buf);
 
 #if GLIBTOP_SUID_LOADAVG
 #define glibtop_get_loadavg_r		glibtop_get_loadavg_p
@@ -65,16 +65,6 @@ void glibtop_init_loadavg_s (glibtop *server);
 void glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_loadavg [];
-extern const unsigned glibtop_types_loadavg [];
-extern const char *glibtop_labels_loadavg [];
-extern const char *glibtop_descriptions_loadavg [];
-
-#endif
 
 G_END_DECLS
 
