@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.28 2004/03/09 23:02:02 hadess Exp $ */
+/* $Id: swap.c,v 1.30 2004/08/28 20:55:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -67,9 +67,9 @@ static struct nlist nlst [] = {
 };
 #endif
 
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 
-#if (__NetBSD_Version__ >= 104000000)
+#if (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 #include <uvm/uvm_extern.h>
 #include <sys/swap.h>
 #else
@@ -78,7 +78,7 @@ static struct nlist nlst [] = {
 
 #endif
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 static int mib_uvmexp [] = { CTL_VM, VM_UVMEXP };
 #else
 /* nlist structure for kernel access */
@@ -109,7 +109,7 @@ glibtop_init_swap_p (glibtop *server)
 #endif
 #endif
 
-#if !(defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000))
+#if !(defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)) && !defined(__OpenBSD__)
 	if (kvm_nlist (server->machine.kd, nlst2) < 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (cnt)");
 		return;
@@ -147,16 +147,16 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	struct kvm_swap kvmsw[16];
 # endif
 
-#elif defined(__bsdi__)	
+#elif defined(__bsdi__)
 	struct swapstats swap;
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 	struct swapent *swaplist;
 #endif
 
 	int nswap, i;
 	int avail = 0, inuse = 0;
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	struct uvmexp uvmexp;
 	size_t length_uvmexp;
 #else
@@ -167,13 +167,13 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	static int swappgsout = -1;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_swap));
 
 	if (server->sysdeps.swap == 0)
 		return;
 
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	length_uvmexp = sizeof (uvmexp);
 	if (sysctl (mib_uvmexp, 2, &uvmexp, &length_uvmexp, NULL, 0)) {
 		glibtop_warn_io_r (server, "sysctl (uvmexp)");
@@ -181,7 +181,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	}
 #else
 	/* This is used to get the `pagein' and `pageout' members. */
-	
+
 	if (kvm_read (server->machine.kd, nlst2[0].n_value,
 		      &vmm, sizeof (vmm)) != sizeof (vmm)) {
 		glibtop_warn_io_r (server, "kvm_read (cnt)");
@@ -197,7 +197,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		buf->pagein = vmm.v_swappgsin - swappgsin;
 		buf->pageout = vmm.v_swappgsout - swappgsout;
 #else
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 		buf->pagein = uvmexp.swapins - swappgsin;
 		buf->pageout = uvmexp.swapouts - swappgsout;
 #else
@@ -211,7 +211,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
         swappgsin = vmm.v_swappgsin;
 	swappgsout = vmm.v_swappgsout;
 #else
-#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000) || defined(__OpenBSD__)
 	swappgsin = uvmexp.swapins;
 	swappgsout = uvmexp.swapouts;
 #else
@@ -391,7 +391,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 	buf->total = swap.swap_total;
 
-#elif defined(__NetBSD__)
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 
 	nswap = swapctl (SWAP_NSWAP, NULL, 0);
 	if (nswap < 0) {
