@@ -10,6 +10,7 @@
 #include <stdarg.h>
 
 #include <fcntl.h>
+#include <unistd.h>
 
 
 unsigned long long
@@ -66,6 +67,8 @@ int try_file_to_buffer(char *buffer, const char *format, ...)
 
 	va_end(pa);
 
+	buffer [0] = '\0';
+
 	if((fd = open (path, O_RDONLY)) < 0)
 		return TRY_FILE_TO_BUFFER_OPEN;
 
@@ -94,3 +97,49 @@ file_to_buffer(glibtop *server, char *buffer, const char *filename)
 }
 
 
+
+
+static unsigned long
+read_boot_time(glibtop *server)
+{
+	char buffer[BUFSIZ];
+	char *btime;
+
+	file_to_buffer(server, buffer, "/proc/stat");
+
+	btime = strstr(buffer, "btime");
+
+	g_return_val_if_fail(btime != NULL, 0UL);
+
+	btime = skip_token(btime);
+	return strtoul(btime, NULL, 10);
+}
+
+
+
+unsigned long
+get_boot_time(glibtop *server)
+{
+	static unsigned long boot_time = 0UL;
+
+	if(G_UNLIKELY(!boot_time))
+	{
+		boot_time = read_boot_time(server);
+	}
+
+	return boot_time;
+}
+
+
+size_t
+get_page_size(void)
+{
+	static size_t pagesize = 0;
+
+	if(G_UNLIKELY(!pagesize))
+	{
+		pagesize = getpagesize();
+	}
+
+	return pagesize;
+}
